@@ -13,7 +13,7 @@ use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 use Carp qw/cluck/;
 
-our $VERSION  = 0.13;
+our $VERSION  = 0.7;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -160,16 +160,20 @@ sub branches_contain {
         next BRANCH if $option{include} && $branch !~ /$option{include}/;
         next BRANCH if $option{exclude} && $branch =~ /$option{exclude}/;
 
+        open my $pipe, '-|', "git log $format -n 1 '$branch'";
         my ($first, $author, $found, $release);
 
-        my ($log) = $workflow->git->log($format, qw/-n 1/, $branch);
-        my ($sha, $time, $user) = split /\s+/, $log, 3;
+        LOG:
+        while (my $log = <$pipe>) {
+            chomp $log;
+            my ($sha, $time, $user) = split /\s+/, $log, 3;
 
-        $first  = $time;
-        $author = $user;
-        if ( $time < $releases[-1]{time} ) {
-            warn "skipping $branch\n" if $option{verbose} && $option{verbose} > 1;
-            next BRANCH;
+            $first  = $time;
+            $author = $user;
+            if ( $time < $releases[-1]{time} ) {
+                warn "skipping $branch\n" if $option{verbose} > 1;
+                next BRANCH;
+            }
         }
 
         my $age = time - $releases[0]{time} + 10 * 60 * 60 * 24;
@@ -202,7 +206,7 @@ sub format_text {
         $max[1] = length $row->[1] if $max[1] < length $row->[1];
     }
     for my $row (@$csv) {
-        printf "%$max[0]s %$max[1]s %s (%.0f days old)\n", @$row[0..4];
+        printf "%$max[0]s %$max[1]s %s (%.0f days old)\n", @$row;
     }
 
     return;
@@ -264,7 +268,6 @@ sub format_html {
 HTML
 
     for my $row (@$csv) {
-        next if !$row && !$row->[2];
         my ($name, $email) = $row->[2] =~ /^<([^>]+)>(.*)$/;
         $row->[0] = $row->[0] eq $releases[-1]{name} ? $row->[0] : qq{<span class="old">$row->[0]</span>};
         $row->[2] = $row->[0] eq $releases[-1]{name} ? $name : qq{<a href="mailto:$email?subject=$row->[1]%20is%20out%20of%20date">$name</a>};
@@ -299,7 +302,7 @@ git-up-to-date - Check that git branches include latest production branch/tag
 
 =head1 VERSION
 
-This documentation refers to git-up-to-date version 0.13
+This documentation refers to git-up-to-date version 0.7
 
 =head1 SYNOPSIS
 
